%bcond_without	ndiff
%bcond_without	zenmap
%bcond_without	pcre

Summary:	Network exploration tool and security scanner
Name:		nmap
Epoch:		1
Version:	7.95
Release:	%mkrel 1
License:	GPLv2
Group:		Networking/Other
URL:		https://nmap.org/
Source0:	http://download.insecure.org/nmap/dist/%{name}-%{version}.tar.bz2
Source1:	%{name}_icons.tar.bz2
#
Patch1:		0001-Don-t-recompile-Python-bytecode-unnecessarily.patch
Patch9:		0009-Python-use-gpep517.patch
#
BuildRequires:	pkgconfig(libpcap)
%if %{with pcre}
BuildRequires:	pkgconfig(libpcre2-8)
%endif
BuildRequires:	pkgconfig(libssh2) >= 1.11
BuildRequires:	pkgconfig(openssl)
BuildRequires:	lua-devel
%if %{with ndiff}
BuildRequires:	pkgconfig(python3)
%endif
%if ! %{with zenmap}
Obsoletes:	%{name}-frontend < %{version}-%{release}
%endif

%description
Nmap is a utility for network exploration or security auditing. It supports
ping scanning (determine which hosts are up), many port scanning techniques
(determine what services the hosts are offering), and TCP/IP fingerprinting
(remote host operating system identification). Nmap also offers flexible target
and port specification, decoy scanning, determination of TCP sequence
predictability characteristics, sunRPC scanning, reverse-identd scanning, and
more.

%if %{with zenmap}
%package	frontend
Summary:	Multi-platform graphical Nmap frontend and results viewer
Group:		Networking/Other
Requires:	%{name} = %{epoch}:%{version}-%{release}
Provides:	zenmap = %{epoch}:%{version}-%{release}
BuildRequires:	pyproject-rpm-macros
BuildRequires:	pkgconfig(python3)
BuildRequires:	python3dist(build)
BuildRequires:	python3dist(setuptools)
Requires:	python3-gi
Requires(post):	desktop-file-utils
Requires(postun): desktop-file-utils

%description	frontend
Zenmap is an Nmap frontend. It is meant to be useful for advanced users and to
make Nmap easy to use by beginners. It was originally derived from Umit, an
Nmap GUI created as part of the Google Summer of Code.
%endif

%prep
%autosetup -p1 -n %{name}-%{version} -a1

rm -rf libpcap libpcre macosx mswin32 libssh2 libz

%build
export CFLAGS="$RPM_OPT_FLAGS -fno-strict-aliasing"
export CXXFLAGS="$RPM_OPT_FLAGS -fno-strict-aliasing"
%configure \
    --with-libpcap=yes \
    --with-liblua=included \
    --with-libssh2=yes \
    --enable-dbus \
    %{?!with_zenmap:--without-zenmap} \
    %{?!with_ndiff:--without-ndiff} \
    %{?with_pcre:--with-pcre2}%{?!with_pcre:--without-pcre2} \
    --without-libpcre \
    --without-nmap-update
%make_build

%if %{with zenmap}
pushd zenmap
%pyproject_wheel
popd
%endif

%install
%if %{with zenmap}
pushd zenmap
%pyproject_install
popd
%endif

%make_install nmapdatadir=%{_datadir}/nmap STRIP=/bin/true

# drop bundled certs
rm -rf %{buildroot}%{_datadir}/ncat/ca-bundle.crt
rmdir %{buildroot}%{_datadir}/ncat

rm -f %{buildroot}%{_datadir}/applications/*.desktop

%if %{with zenmap}
# XDG menu
install -d %{buildroot}%{_datadir}/applications
cat > %{buildroot}%{_datadir}/applications/%{_real_vendor}-%{name}.desktop << EOF
[Desktop Entry]
Name=Nmap
GenericName=GUI Port Scanner
Comment=A frontend for the Nmap Security Scanner
Exec=zenmap %%F
Icon=zenmap
Terminal=false
Type=Application
Categories=System;Monitor;
Keywords=network;scan;scanner;IP;security;
EOF

mkdir -p %{buildroot}%{_iconsdir}/hicolor/256x256/apps
install -m0644 zenmap/zenmapCore/data/pixmaps/zenmap.png %{buildroot}%{_iconsdir}/hicolor/256x256/apps/
%endif

%find_lang %{name} --with-man

# cleanup
rm -f %{buildroot}%{_bindir}/uninstall_*

%files -f %{name}.lang
%doc HACKING docs/README docs/nmap.usage.txt
%license LICENSE
%{_bindir}/%{name}
%{_bindir}/ncat
%if %{with ndiff}
%{_bindir}/ndiff
%{_mandir}/man1/ndiff.*
%endif
%{_bindir}/nping
%{_datadir}/%{name}/
%{_mandir}/man1/nmap.*
%{_mandir}/man1/ncat.*
%{_mandir}/man1/nping.*

%if %{with zenmap}
%files frontend
%{_bindir}/nmapfe
%{_bindir}/xnmap
%{_bindir}/zenmap
%{python3_sitelib}/*
%{_datadir}/applications/*.desktop
%{_iconsdir}/hicolor/*/apps/zenmap.png
%{_mandir}/man1/zenmap.1*
%endif


%changelog
* Sun Oct 13 2024 daviddavid <daviddavid> 1:7.95-1.mga9
+ Revision: 2105700
- new version: 7.95 (mga#33606)

* Mon Jun 19 2023 daviddavid <daviddavid> 1:7.94-2.mga9
+ Revision: 1962558
- switch to pcre2 support (from https://github.com/nmap/nmap/pull/2668)

* Sun May 21 2023 daviddavid <daviddavid> 1:7.94-1.mga9
+ Revision: 1957654
- new version: 7.94

* Sat Apr 29 2023 daviddavid <daviddavid> 1:7.93-2.git20230321.1.mga9
+ Revision: 1955296
- update to latest git snapshot 20230321
- zenmap and ndiff are now ported to python3 so let's re-enabled them

* Tue Sep 06 2022 guillomovitch <guillomovitch> 1:7.93-1.mga9
+ Revision: 1884395
- new version 7.93

* Sat Mar 26 2022 luigiwalser <luigiwalser> 1:7.92-1.mga9
+ Revision: 1828111
- 7.92

* Sat Oct 02 2021 tmb <tmb> 1:7.91-3.mga9
+ Revision: 1747330
- rebuild for openssl 3.0.0

* Sat Apr 03 2021 wally <wally> 1:7.91-2.mga9
+ Revision: 1712890
- drop bundled ca-bundle.crt
- rebuild with lua 5.4

* Wed Oct 14 2020 guillomovitch <guillomovitch> 1:7.91-1.mga8
+ Revision: 1636092
- new version 7.91

* Thu May 21 2020 wally <wally> 1:7.80-4.mga8
+ Revision: 1586705
- drop unneeded %%_disable_ld_no_undefined macro

* Sun Feb 16 2020 umeabot <umeabot> 1:7.80-3.mga8
+ Revision: 1535864
- Mageia 8 Mass Rebuild
+ wally <wally>
- replace deprecated %%configure2_5x

* Sun Oct 13 2019 wally <wally> 1:7.80-2.mga8
+ Revision: 1452822
- build without python2 tools ndiff and zenmap (frontend)

* Sat Aug 10 2019 kekepower <kekepower> 1:7.80-1.1.mga8
+ Revision: 1428606
- Update to version 7.80
- Build with Lua 5.3

* Sun Sep 23 2018 umeabot <umeabot> 1:7.70-2.mga7
+ Revision: 1299750
- Mageia 7 Mass Rebuild

* Thu Mar 22 2018 kekepower <kekepower> 1:7.70-1.mga7
+ Revision: 1211298
- Update to version 7.70
- Added BR for pkgconfig(lua)
- Added BR for pkgconfig(libssh2)

* Wed Aug 02 2017 guillomovitch <guillomovitch> 1:7.40-2.mga7
+ Revision: 1133978
- rebuild for latest openssl

* Sat Dec 24 2016 guillomovitch <guillomovitch> 1:7.40-1.mga6
+ Revision: 1076948
- new version 7.40

* Sat Apr 09 2016 guillomovitch <guillomovitch> 1:7.12-1.mga6
+ Revision: 999916
- new version 7.12

* Wed Mar 02 2016 umeabot <umeabot> 1:7.01-3.mga6
+ Revision: 983803
- Rebuild for openssl
- Mageia 6 Mass Rebuild

* Sat Dec 12 2015 guillomovitch <guillomovitch> 1:7.01-1.mga6
+ Revision: 909656
- new version 7.01

* Sun Nov 22 2015 guillomovitch <guillomovitch> 1:7.00-1.mga6
+ Revision: 904932
- new version 7.00

* Fri Aug 21 2015 tmb <tmb> 1:6.47-5.mga6
+ Revision: 867821
- rebuild for new gcc

* Wed Oct 15 2014 umeabot <umeabot> 1:6.47-4.mga5
+ Revision: 746021
- Second Mageia 5 Mass Rebuild

* Sat Sep 27 2014 tv <tv> 1:6.47-3.mga5
+ Revision: 727477
- rebuild for missing pythoneggs deps

* Tue Sep 16 2014 umeabot <umeabot> 1:6.47-2.mga5
+ Revision: 682895
- Mageia 5 Mass Rebuild

* Fri Sep 05 2014 luigiwalser <luigiwalser> 1:6.47-1.mga5
+ Revision: 672360
- 6.47
+ pterjan <pterjan>
- Rebuild for new Python

* Mon Apr 28 2014 guillomovitch <guillomovitch> 1:6.46-1.mga5
+ Revision: 618620
- new version 6.46

* Tue Oct 22 2013 umeabot <umeabot> 1:6.40-3.mga5
+ Revision: 542867
- Mageia 4 Mass Rebuild

* Tue Oct 15 2013 pterjan <pterjan> 1:6.40-2.mga4
+ Revision: 497961
- Rebuild to add different pythonegg provides for python 2 and 3

* Thu Aug 01 2013 guillomovitch <guillomovitch> 1:6.40-1.mga4
+ Revision: 462086
- new version

* Sun Mar 17 2013 lmenut <lmenut> 1:6.25-3.mga3
+ Revision: 403609
- rebuild for new rpm-mageia-setup
  do not own man lang directories (mga #9055)
+ umeabot <umeabot>
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Mon Dec 03 2012 guillomovitch <guillomovitch> 1:6.25-1.mga3
+ Revision: 325846
- new version

* Sat Dec 01 2012 fwang <fwang> 1:6.01-3.mga3
+ Revision: 323817
- rebuild for new pcre

* Thu Sep 20 2012 guillomovitch <guillomovitch> 1:6.01-2.mga3
+ Revision: 296323
- use external libpcap

* Tue Jun 26 2012 guillomovitch <guillomovitch> 1:6.01-1.mga3
+ Revision: 263978
- new version
- drop mandriva patches (undocumented purpose)
- use lua5.1 for script engine
+ luigiwalser <luigiwalser>
- 6.01

* Tue May 29 2012 guillomovitch <guillomovitch> 1:6.00-1.mga3
+ Revision: 249112
- do not build nmap-update
- new version

* Sun Feb 19 2012 luigiwalser <luigiwalser> 1:5.51.6-1.mga2
+ Revision: 210652
- 5.51.6
- remove upstreamed patch 3

* Tue Aug 30 2011 guillomovitch <guillomovitch> 1:5.51-5.mga2
+ Revision: 136687
- fix service-probes regexp file

* Tue Apr 26 2011 wally <wally> 1:5.51-4.mga1
+ Revision: 91798
- fix desktop file name (mga#954)
- fix exec line in desktop file
- use find_lang macro with --with-man
- drop buildroot definition

* Sat Apr 16 2011 pterjan <pterjan> 1:5.51-3.mga1
+ Revision: 86297
- Fix a non literal format string
- Drop md2 patch, code was removed upstream
- Update to 5.51

* Sun Jan 23 2011 pterjan <pterjan> 1:5.21-3.mga1
+ Revision: 34989
- Drop old scriptlets
+ kharec <kharec>
- imported package nmap


* Thu Apr 08 2010 Eugeni Dodonov <eugeni@mandriva.com> 1:5.21-3mdv2010.1
+ Revision: 533030
- Do not build md2 (openssl 1.0.0 does not supports it).
  Fix building python bytecode.
- Rebuild for new openssl

* Fri Feb 26 2010 Oden Eriksson <oeriksson@mandriva.com> 1:5.21-2mdv2010.1
+ Revision: 511597
- rebuilt against openssl-0.9.8m

* Sat Jan 30 2010 Frederik Himpe <fhimpe@mandriva.org> 1:5.21-1mdv2010.1
+ Revision: 498550
- Update to new version 5.21
- Rediff libpcap-filter patch
- Remove string literal patch (not needed anymore)
- Add man page translations to file list

* Fri Oct 09 2009 Thierry Vignaud <tv@mandriva.org> 1:5.00-2mdv2010.0
+ Revision: 456418
- do not package huge changelog

* Fri Jul 17 2009 Guillaume Rousse <guillomovitch@mandriva.org> 1:5.00-1mdv2010.0
+ Revision: 396922
- new version
- no need for a patch to avoid stripping, a make parameter is enough

* Sat Dec 27 2008 Funda Wang <fwang@mandriva.org> 1:4.76-3mdv2009.1
+ Revision: 319687
- rebuild for new python

* Mon Dec 22 2008 Oden Eriksson <oeriksson@mandriva.com> 1:4.76-2mdv2009.1
+ Revision: 317516
- rediffed one fuzzy patch (P1)
- fix build with -Werror=format-security (P3)

* Fri Sep 12 2008 Frederik Himpe <fhimpe@mandriva.org> 1:4.76-1mdv2009.0
+ Revision: 284235
- update to new version 4.76

* Tue Sep 09 2008 Frederik Himpe <fhimpe@mandriva.org> 1:4.75-1mdv2009.0
+ Revision: 283295
- Update to new version 4.75 (nselib-bin directory has been removed
  by upstream)

* Tue Jul 15 2008 Oden Eriksson <oeriksson@mandriva.com> 1:4.68-1mdv2009.0
+ Revision: 236088
- 4.68
- 4.60
- rediffed P2

  + Pixel <pixel@mandriva.com>
    - rpm filetriggers deprecates update_menus/update_scrollkeeper/update_mime_database/update_icon_cache/update_desktop_database/post_install_gconf_schemas

* Sat Jan 26 2008 Guillaume Rousse <guillomovitch@mandriva.org> 1:4.53-1mdv2008.1
+ Revision: 158316
- update to new version 4.53

  + Olivier Blin <oblin@mandriva.com>
    - restore BuildRoot

  + Thierry Vignaud <tv@mandriva.org>
    - kill re-definition of %%buildroot on Pixel's request

* Thu Dec 13 2007 Oden Eriksson <oeriksson@mandriva.com> 1:4.50-1mdv2008.1
+ Revision: 119447
- 4.50
- rediffed P2

* Fri Aug 31 2007 Funda Wang <fwang@mandriva.org> 1:4.20-2mdv2008.0
+ Revision: 76517
- drop old menu
- remove quotes of comments


* Fri Dec 08 2006 Oden Eriksson <oeriksson@mandriva.com> 4.20-1mdv2007.0
+ Revision: 93641
- 4.20
- rediffed the nmap-4.00-libpcap-filter.diff patch (P0)

* Thu Oct 26 2006 Oden Eriksson <oeriksson@mandriva.com> 1:4.11-2mdv2007.0
+ Revision: 72797
- synced with opensuse patches; P0,P1,P2
- use bundled libpcap and libdnet, fixes #22559
- fix the xdg menu stuff
- Import nmap

* Sun Jun 25 2006 Giuseppe Ghibò <ghibo@mandriva.com> 1:4.11-1mdv2007.0
- 4.11.

* Wed Jun 14 2006 Oden Eriksson <oeriksson@mandriva.com> 1:4.10-1mdv2007.0
- 4.10 (Major feature enhancements)

* Tue Apr 25 2006 Oden Eriksson <oeriksson@mandriva.com> 4.03-1mdk
- 4.03 (Minor bugfixes)

* Sat Feb 11 2006 Oden Eriksson <oeriksson@mandriva.com> 4.01-1mdk
- 4.01 (Minor bugfixes)

* Wed Feb 01 2006 Oden Eriksson <oeriksson@mandriva.com> 4.00-1mdk
- 4.00 (Major feature enhancements)

* Wed Jan 25 2006 Oden Eriksson <oeriksson@mandriva.com> 3.99-1mdk
- 3.99 (Major feature enhancements)

* Sat Dec 10 2005 Oden Eriksson <oeriksson@mandriva.com> 3.95-1mdk
- 3.95 (Major feature enhancements)

* Sun Nov 13 2005 Oden Eriksson <oeriksson@mandriva.com> 3.93-2mdk
- rebuilt against openssl-0.9.8a

* Fri Sep 23 2005 Oden Eriksson <oeriksson@mandrakesoft.com> 3.93-1mdk
- 3.93
- build it against system libs
- added one lib64 fix

* Mon Feb 07 2005 Oden Eriksson <oeriksson@mandrakesoft.com> 3.81-1mdk
- 3.81

* Sun Feb 06 2005 Oden Eriksson <oeriksson@mandrakesoft.com> 3.80-1mdk
- 3.80

* Thu Dec 23 2004 Thierry Vignaud <tvignaud@mandrakesoft.com> 3.78-1mdk
- new release

* Thu Nov 11 2004 Per Øyvind Karlsen <peroyvind@linux-mandrake.com> 3.75-1mdk
- 3.75

* Fri Jul 09 2004 Thierry Vignaud <tvignaud@mandrakesoft.com> 3.55-1mdk
- new release
- fix laurent's entry

* Sat Jun 05 2004 Laurent Montel <lmontel@mandrakesoft.com> 3.50-5mdk
- Rebuild

* Fri May 14 2004 Michael Scherer <misc@mandrake.org> 3.50-4mdk 
- rebuild for cooker

* Thu Mar 25 2004 Gwenole Beauchesne <gbeauchesne@mandrakesoft.com> 3.50-3.1mdk
- recognize amd64 again

* Fri Mar 12 2004 David Baudens <baudens@mandrakesoft.com> 3.50-3mdk
- Fix menu

* Mon Feb 23 2004 Abel Cheung <deaddog@deaddog.org> 3.50-2mdk
- Add epoch to dependency

* Sat Jan 24 2004 Michael Scherer <misc@mandrake.org> 3.50-1mdk
- 3.50

